*********************************
Propertyshelf MLS Plone Embedding
*********************************

`ps.plone.mls`_ is an add-on for the content management system `Plone`_.
It activates the embedding of real estate listings from the `Propertyshelf`_ MLS.

.. only:: html

  Contents
  ========

.. toctree::
   :maxdepth: 2

   configuration
   listing_collections
   listing_search
   development


.. only:: html

  Indices and tables
  ==================

  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`


.. only:: html

  Add-On Statistics
  =================

  .. image:: https://travis-ci.org/propertyshelf/ps.plone.mls.png?branch=master
      :target: http://travis-ci.org/propertyshelf/ps.plone.mls
      :alt: Travis CI status

  .. image:: https://coveralls.io/repos/propertyshelf/ps.plone.mls/badge.png?branch=master
      :target: https://coveralls.io/r/propertyshelf/ps.plone.mls?branch=master
      :alt: Coveralls status

  .. image:: https://badge.fury.io/py/ps.plone.mls.png
      :target: http://badge.fury.io/py/ps.plone.mls
      :alt: Fury Python

  .. image:: https://badge.fury.io/gh/propertyshelf%2Fps.plone.mls.png
      :target: http://badge.fury.io/gh/propertyshelf%2Fps.plone.mls
      :alt: Fury Github


.. _`Plone`: http://plone.org
.. _`Propertyshelf`: http://propertyshelf.com
.. _`ps.plone.mls`: https://pypi.python.org/pypi/ps.plone.mls
